// 将地图相关的变量和函数提升到全局作用域
let map = null;
let marker = null;
let infoWindow = null;

// 地图数据配置
const mapData = {
    address: {
        zh: '广东省深圳市南山区粤海街道麻岭社区麻雀岭工业区M-6栋中钢大厦5A010',
        en: '5A010, Zhonggang Building, M-6 Building, Maque Ridge Industrial Zone, Ma Ling Community, Yuehai Street, Nanshan District, Shenzhen, Guangdong Province'
    },
    companyName: {
        zh: '深圳汉晶电子信息有限公司',
        en: 'Shenzhen Hanjing Electronic Information Co., Ltd'
    },
    contactInfo: {
        zh: {
            address: '地址',
            phone: '电话',
            email: '邮箱'
        },
        en: {
            address: 'Address',
            phone: 'Phone',
            email: 'Email'
        }
    }
};

// 创建信息窗体内容
function createInfoWindowContent(lang) {
    return `
        <div class="info-content" style="padding: 15px;">
            <h4 style="margin: 0 0 10px 0; color: #100B4E; font-size: 16px;">${mapData.companyName[lang]}</h4>
            <p style="margin: 0 0 8px 0; font-size: 13px;color: #100B4E;">
                <strong>${mapData.contactInfo[lang].address}：</strong>${mapData.address[lang]}
            </p>
            <p style="margin: 0 0 8px 0; font-size: 13px; color: #100B4E;">
                <strong>${mapData.contactInfo[lang].phone}：</strong>13420976989
            </p>
            <p style="margin: 0; font-size: 13px; color: #100B4E;">
                <strong>${mapData.contactInfo[lang].email}：</strong>fu.bin@hjsilicon.com
            </p>
        </div>
    `;
}

// 更新地图信息
function updateMapInfo(lang) {
    if (marker && infoWindow) {
        // 更新标记标题
        marker.setTitle(mapData.companyName[lang]);
        
        // 更新信息窗体内容
        infoWindow.setContent(createInfoWindowContent(lang));
        
        // 如果信息窗体是打开状态，重新打开以更新内容
        if (infoWindow.getIsOpen()) {
            infoWindow.open(map, marker.getPosition());
        }
    }
}

// 初始化地图
function initAMap() {
    try {
        // 先加载所需插件
        AMap.plugin(['AMap.Geocoder', 'AMap.ToolBar', 'AMap.Scale'], function() {
            const geocoder = new AMap.Geocoder({
                city: "深圳",
                radius: 1000
            });
            
            geocoder.getLocation(mapData.address.zh, function(status, result) {
                if (status === 'complete' && result.info === 'OK') {
                    const lnglat = result.geocodes[0].location;
                    
                    // 创建地图实例
                    map = new AMap.Map('mapContainer', {
                        zoom: 16,
                        center: [lnglat.lng, lnglat.lat],
                        viewMode: '3D',
                        resizeEnable: true,
                        pitch: 40,
                        mapStyle: 'amap://styles/normal'
                    });
                    
                    // 创建标记
                    marker = new AMap.Marker({
                        position: [lnglat.lng, lnglat.lat],
                        title: mapData.companyName[window.currentLang],
                        animation: 'AMAP_ANIMATION_DROP',
                        offset: new AMap.Pixel(-13, -30)
                    });
                    
                    map.add(marker);
                    
                    // 创建信息窗体
                    infoWindow = new AMap.InfoWindow({
                        content: createInfoWindowContent(window.currentLang),
                        offset: new AMap.Pixel(0, -30),
                        closeWhenClickMap: true
                    });
                    
                    // 地图加载完成后打开信息窗体
                    map.on('complete', function() {
                        infoWindow.open(map, [lnglat.lng, lnglat.lat]);
                    });
                    
                    // 点击标记时打开信息窗体
                    marker.on('click', function() {
                        infoWindow.open(map, marker.getPosition());
                    });
                    
                    // 添加控件
                    map.addControl(new AMap.ToolBar({
                        position: 'RB'
                    }));
                    
                    map.addControl(new AMap.Scale());
                    
                    // 确保标记点居中显示
                    map.setFitView([marker]);
                    
                    // 响应式处理
                    window.addEventListener('resize', function() {
                        map.resize();
                        map.setCenter([lnglat.lng, lnglat.lat]);
                    });
                } else {
                    console.error('地址解析失败:', result);
                    document.getElementById('mapContainer').innerHTML = 
                        '<div style="text-align:center;padding:20px;color:#f00;">地址定位失败，请刷新重试</div>';
                }
            });
        });
    } catch (error) {
        console.error('地图初始化失败:', error);
        document.getElementById('mapContainer').innerHTML = 
            '<div style="text-align:center;padding:20px;color:#f00;">地图加载失败，请刷新重试</div>';
    }
}



// DOM加载完成时初始化
document.addEventListener('DOMContentLoaded', function() {
    if (typeof AMap !== 'undefined') {
        initAMap();
    }

    const langData = {
        zh: {
            btn: "English",
            logo: "../imgs/svg/logo.svg",
            title: "深圳汉晶电子信息有限公司",
            // 顶部
            topBannerTitle: "公司介绍",
            topBannerDesc: "我们是一家专注于集成电路设计的高科技公司,致力于为客户提供从芯片设计到量产的全流程服务。我们的团队拥有丰富的行业经验，采用最先进的工具和技术，为客户提供高品质的芯片解决方案。我们始终坚持以客户为中心，以技术为驱动，致力于推动集成电路行业的创新与发展。",
            // 愿景/使命/价值观
            visionTitle: "我们的愿景",
            visionDesc: "聚焦高性能芯片设计，打造全球竞争力核心，以技术创新驱动产业升级，引领智能生态新未来。",
            missionTitle: "我们的使命",
            missionDesc: "通过在集成电路设计、应用解决方案和人工智能技术的持续创新,我们提供高可靠、智能的产品和服务，为客户创造价值，让人们的生活更加美好!",
            valueTitle: "我们的核心价值观",
            valueDesc: "客户至上、艰苦奋斗、创新卓越、合作共赢",
            emailLeftTitle: "我们准备好了",
            emailLeftText: "如果您有更多的需求，请联系我们",
            bannertopBG: "../imgs/us/corporateCultureConcept.svg",

        },
        en: {
            btn: "简体中文",
            logo: "../imgs/svg/logo_en.svg",
            title: "SZHJ Electronic Information Co., Ltd",
            // 顶部
            topBannerTitle: "Company Introduction",
            topBannerDesc: "We are a high-tech company focused on integrated circuit design, dedicated to providing customers with full-process services from chip design to mass production. Our team has extensive industry experience and uses the most advanced tools and technologies to provide customers with high-quality chip solutions. We always adhere to a customer-centric and technology-driven approach, committed to promoting innovation and development in the integrated circuit industry.",
            // 愿景/使命/价值观
            visionTitle: "Our Vision",
            visionDesc: "Focus on high-performance chip design, build globally competitive cores, drive industrial upgrading with technological innovation, and lead the new future of the intelligent ecosystem.",
            missionTitle: "Our Mission",
            missionDesc: "Through continuous innovation in integrated circuit design, application solutions, and artificial intelligence technology, we provide highly reliable and intelligent products and services, create value for customers, and make people's lives better!",
            valueTitle: "Our Core Values",
            valueDesc: "Customer First, Hard Work, Excellence in Innovation, Win-Win Cooperation",
            emailLeftTitle: "We're ready.",
            emailLeftText: "If you have more needs, please contact us!",
            bannertopBG: "../imgs/us/corporateCultureConcept_en.svg",
        
        }   
    };

       // 使用全局的 currentLang
       if (!window.currentLang) {
        window.currentLang = localStorage.getItem('siteLang') || "zh";
    }

    function applyLang(lang) {
        const data = langData[lang];

        // logo
        document.getElementById("logo-img").src = data.logo;
        document.getElementById("footerLogo").src = data.logo;

        // 页面标题
        document.title = data.title;
        document.querySelector(".footerBoxRightTitle").textContent = data.title;

        // 顶部标题和描述
        document.querySelector('.topBannerLeftTitle p:nth-child(1)').textContent = data.topBannerTitle;
        document.querySelector('.topBannerLeftTitle p:nth-child(2)').textContent = data.topBannerDesc;

        // 愿景
        document.querySelector('.textOne .Right p:nth-child(1)').textContent = data.visionTitle;
        document.querySelector('.textOne .Right p:nth-child(2)').textContent = data.visionDesc;

        // 使命
        document.querySelector('.textTwo .Right p:nth-child(1)').textContent = data.missionTitle;
        document.querySelector('.textTwo .Right p:nth-child(2)').textContent = data.missionDesc;

        // 价值观
        document.querySelector('.textThree .Right p:nth-child(1)').textContent = data.valueTitle;
        document.querySelector('.textThree .Right p:nth-child(2)').textContent = data.valueDesc;

        // 邮箱区
        document.querySelector(".emailLeftTitle").textContent = data.emailLeftTitle;
        document.querySelector(".emailLeftText").textContent = data.emailLeftText;

        // 按钮文本
        document.getElementById("lang-toggle").textContent = data.btn;
        document.querySelector('.bannertop').style.backgroundImage = `url(${data.bannertopBG})`;

        // 英文样式调整（如有需要可扩展）
        const visionPs = document.querySelectorAll('.textOne .Right p');
        const missionPs = document.querySelectorAll('.textTwo .Right p');
        const valuePs = document.querySelectorAll('.textThree .Right p');
        const allPs = [...visionPs, ...missionPs, ...valuePs];
    
        if (lang === 'en') {
            document.querySelector('.topBannerLeftTitle p:nth-child(1)').classList.add('en');
            document.querySelector('.topBannerLeftTitle p:nth-child(2)').classList.add('en');
            allPs.forEach(p => p.classList.add('en'));

      
        } else {
            allPs.forEach(p => p.classList.remove('en'));

            document.querySelector('.topBannerLeftTitle p:nth-child(1)').classList.remove('en');
            document.querySelector('.topBannerLeftTitle p:nth-child(2)').classList.remove('en');
        }


    }



    // 语言切换处理函数
    function handleLangToggle() {
        window.currentLang = window.currentLang === "zh" ? "en" : "zh";
        localStorage.setItem('siteLang', window.currentLang);
        applyLang(window.currentLang);
        updateMapInfo(window.currentLang);
    }

  // 初始化
  applyLang(window.currentLang);

    // 事件绑定
    document.getElementById("lang-toggle").addEventListener("click", handleLangToggle);
    document.getElementById("lang-toggle").addEventListener("keydown", e => {
        if (e.key === "Enter" || e.key === " ") handleLangToggle();
    });







});


// 回调函数
window.initMap = function() {
    if (typeof AMap !== 'undefined') {
        initAMap();
    }
};